==> jc-1.4.0.tar.gz: gnu/java/awt/BitwiseXORComposite.h <==
// public class gnu.java.awt.BitwiseXORComposite

// class file dependencies
// @dep_class 3219b3341c67d35 gnu_java_awt_BitwiseXORComposite
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_BitwiseXORComposite_H_
#define _JC_gnu_java_awt_BitwiseXORComposite_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_CompositeContext$object;
struct _jc_java_awt_RenderingHints$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_BitwiseXORComposite$sub_refs	_jc_gnu_java_awt_BitwiseXORComposite$sub_refs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite$sub_nonrefs	_jc_gnu_java_awt_BitwiseXORComposite$sub_nonrefs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite$refs	_jc_gnu_java_awt_BitwiseXORComposite$refs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite$nonrefs	_jc_gnu_java_awt_BitwiseXORComposite$nonrefs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite$object	_jc_gnu_java_awt_BitwiseXORComposite$object;

typedef const struct _jc_gnu_java_awt_BitwiseXORComposite$vmethods	_jc_gnu_java_awt_BitwiseXORComposite$vmethods;
typedef const struct _jc_gnu_java_awt_BitwiseXORComposite$vtable	_jc_gnu_java_awt_BitwiseXORComposite$vtable;
typedef const struct _jc_gnu_java_awt_BitwiseXORComposite$vtype	_jc_gnu_java_awt_BitwiseXORComposite$vtype;

// Constructors
extern void _jc_gnu_java_awt_BitwiseXORComposite$method$_init$d42470fc2dba686a(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite$object *, struct _jc_java_awt_Color$object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_java_awt_BitwiseXORComposite$method$createContext$f4115af9469e4273(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_RenderingHints$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_BitwiseXORComposite$method_info$createContext$f4115af9469e4273;

// Virtual methods structure
struct _jc_gnu_java_awt_BitwiseXORComposite$vmethods {
	struct _jc_object	*(*createContext$f4115af9469e4273)(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_RenderingHints$object *);
};

// Vtable
struct _jc_gnu_java_awt_BitwiseXORComposite$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_BitwiseXORComposite$vmethods	gnu_java_awt_BitwiseXORComposite;
};

// Vtype
struct _jc_gnu_java_awt_BitwiseXORComposite$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_BitwiseXORComposite$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_BitwiseXORComposite$sub_refs {
	struct _jc_java_awt_Color$object	*xorColor;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_BitwiseXORComposite$refs {
    _jc_gnu_java_awt_BitwiseXORComposite$sub_refs	gnu_java_awt_BitwiseXORComposite;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_BitwiseXORComposite$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_BitwiseXORComposite$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_BitwiseXORComposite$sub_nonrefs	gnu_java_awt_BitwiseXORComposite;
};

// Object instance structure
struct _jc_gnu_java_awt_BitwiseXORComposite$object {
	_jc_gnu_java_awt_BitwiseXORComposite$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_BitwiseXORComposite$vtype	*vtype;
	_jc_gnu_java_awt_BitwiseXORComposite$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_BitwiseXORComposite$vtype _jc_gnu_java_awt_BitwiseXORComposite$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_BitwiseXORComposite, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_BitwiseXORComposite$class_object;

#endif	/* _JC_gnu_java_awt_BitwiseXORComposite_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/BitwiseXORComposite.h <==
// public class gnu.java.awt.BitwiseXORComposite

// class file dependencies
// @dep_class 3219b3341c67d35 gnu_java_awt_BitwiseXORComposite
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_BitwiseXORComposite_H_
#define _JC_gnu_java_awt_BitwiseXORComposite_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_CompositeContext$object;
struct _jc_java_awt_RenderingHints$object;
struct _jc_java_awt_image_ColorModel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_BitwiseXORComposite$sub_refs	_jc_gnu_java_awt_BitwiseXORComposite$sub_refs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite$sub_nonrefs	_jc_gnu_java_awt_BitwiseXORComposite$sub_nonrefs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite$refs	_jc_gnu_java_awt_BitwiseXORComposite$refs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite$nonrefs	_jc_gnu_java_awt_BitwiseXORComposite$nonrefs;
typedef struct _jc_gnu_java_awt_BitwiseXORComposite$object	_jc_gnu_java_awt_BitwiseXORComposite$object;

typedef const struct _jc_gnu_java_awt_BitwiseXORComposite$vmethods	_jc_gnu_java_awt_BitwiseXORComposite$vmethods;
typedef const struct _jc_gnu_java_awt_BitwiseXORComposite$vtable	_jc_gnu_java_awt_BitwiseXORComposite$vtable;
typedef const struct _jc_gnu_java_awt_BitwiseXORComposite$vtype	_jc_gnu_java_awt_BitwiseXORComposite$vtype;

// Constructors
extern void _jc_gnu_java_awt_BitwiseXORComposite$method$_init$d42470fc2dba686a(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_java_awt_BitwiseXORComposite$method$createContext$f4115af9469e4273(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_RenderingHints$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_BitwiseXORComposite$method_info$createContext$f4115af9469e4273;

// Virtual methods structure
struct _jc_gnu_java_awt_BitwiseXORComposite$vmethods {
	struct _jc_object	*(*createContext$f4115af9469e4273)(_jc_env *, struct _jc_gnu_java_awt_BitwiseXORComposite$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_image_ColorModel$object *, struct _jc_java_awt_RenderingHints$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_BitwiseXORComposite$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_BitwiseXORComposite$vmethods	gnu_java_awt_BitwiseXORComposite;
};

// Vtype
struct _jc_gnu_java_awt_BitwiseXORComposite$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_BitwiseXORComposite$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_BitwiseXORComposite$sub_refs {
	struct _jc_java_awt_Color$object	*xorColor;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_BitwiseXORComposite$refs {
    _jc_gnu_java_awt_BitwiseXORComposite$sub_refs	gnu_java_awt_BitwiseXORComposite;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_BitwiseXORComposite$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_BitwiseXORComposite$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_BitwiseXORComposite$sub_nonrefs	gnu_java_awt_BitwiseXORComposite;
};

// Object instance structure
struct _jc_gnu_java_awt_BitwiseXORComposite$object {
	_jc_gnu_java_awt_BitwiseXORComposite$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_BitwiseXORComposite$vtype	*vtype;
	_jc_gnu_java_awt_BitwiseXORComposite$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_BitwiseXORComposite$vtype _jc_gnu_java_awt_BitwiseXORComposite$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_BitwiseXORComposite, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_BitwiseXORComposite$class_object;

#endif	/* _JC_gnu_java_awt_BitwiseXORComposite_H_ */
